"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrettyEmailWrap = void 0;
var jsx_runtime_1 = require("react/jsx-runtime");
var react_1 = require("react");
/**
 * Insert [Word Break Opportunity tags](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/wbr) (`<wbr />`) to help an email address wrap in a human readable way.
 *
 * @example
 * ```
 * <PrettyEmailWrap>name@domain.com</PrettyEmailWrap> // name<wbr />@domain.<wbr />com
 * ```
 */
var PrettyEmailWrap = function (_a) {
    var children = _a.children;
    if (children.length === 0) {
        return null;
    }
    if (!["@", ".", "+", "-", "_"].some(function (character) { return children.includes(character); })) {
        return null;
    }
    var split = children.split(/([@,.,+,-,_])/g);
    var replace = split.map(function (fragment, i) {
        if (fragment === "@") {
            return ((0, jsx_runtime_1.jsxs)(react_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("wbr", {}), "@"] }, i));
        }
        if (fragment === "." ||
            fragment === "+" ||
            fragment === "-" ||
            fragment === "_") {
            return ((0, jsx_runtime_1.jsxs)(react_1.Fragment, { children: [fragment, (0, jsx_runtime_1.jsx)("wbr", {})] }, i));
        }
        return (0, jsx_runtime_1.jsx)(react_1.Fragment, { children: fragment }, i);
    });
    return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: replace });
};
exports.PrettyEmailWrap = PrettyEmailWrap;
